#! /usr/bin/env python
# -*- coding: utf-8 -*-
# Andrés Aguirre Dorelo
# MINA/INCO/UDELAR
# basic ax12 actuator control
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

from Xlib import X, display, ext, xobject
from Xlib.ext import record, xtest, shape, xinerama
from Xlib.xobject import colormap, drawable
import time

dis = display.Display()
scr = dis.screen()
win = scr.root
colormap = scr.default_colormap
lineActive = False
lineWidth = 10
color = colormap.alloc_color(0, 0, 65535)
gc = win.create_gc(
		line_width = lineWidth,
		line_style = X.LineSolid,
		fill_style = X.FillOpaqueStippled,
		fill_rule  = X.WindingRule,
		cap_style  = X.CapButt,
		join_style = X.JoinMiter,
		foreground = color.pixel,
		background = scr.black_pixel,
		graphics_exposures = True,
		subwindow_mode = X.IncludeInferiors,
		)

def setLineWidth(width):
	global lineWidth
	lineWidth = width

def showLine(active):
	global lineActive
	if active == 0:
		lineActive = False
	else:
		lineActive = True


def setLineColor(red,green,blue):
	global color
	cred = (long(red) & long(255)) << 8  | long(255)
	cgreen = (long(green) & long(255)) << 8 | long(255)
	cblue = (long(blue) & long(255)) << 8 | long(255)
	color = colormap.alloc_color(cred, cgreen, cblue)

def createRelativeMouseEvent(deltaX, deltaY):
	d = display.Display()
	#move pointer to set relative location
	d.warp_pointer(deltaX,deltaY)
	d.sync()

def createAbsoluteMouseEvent(x,y):
	#move pointer to set absolute location
	data = win.get_geometry()
	height = data.height
	if lineActive:
		#global gc
		#global color
		#global lineWidth
		win.line(gc, x, 0, x, height)
	win.warp_pointer(x,y)
	dis.sync()

def getMousePosition():
	d = display.Display()
	data = d.screen().root.query_pointer()._data
	return data['root_x'], data['root_y']

def getScreenResolution():
	d = display.Display()
	resolution = d.screen().root.get_geometry()
	return resolution.width, resolution.height

def buttonPress(button):
	d = display.Display()
	ext.xtest.fake_input(d,X.ButtonPress,button)
	d.sync()

def buttonRelease(button):
	d = display.Display()
	ext.xtest.fake_input(d,X.ButtonRelease,button)
	d.sync()

def clickButton(button):
	d = display.Display()
	#press button 1, for middle mouse button use 2, for opposite button use 3
	ext.xtest.fake_input(d,X.ButtonPress,button)
	d.sync()
	#to make click we need to release the same button
	ext.xtest.fake_input(d, X.ButtonRelease,button)
	d.sync()

def pressButton(button):
	d = display.Display()
	#press button 1, for middle mouse button use 2, for opposite button use 3
	ext.xtest.fake_input(d,X.ButtonPress,button)
	d.sync()

def releaseButton(button):
	d = display.Display()
	#to make click we need to release the same button
	ext.xtest.fake_input(d, X.ButtonRelease,button)
	d.sync()

